Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: components/offline_pages/core/prefetch/prefetch_dispatcher.h

Issue 2914703002: [Offline Prefetch] Backoff support for PrefetchBackgroundTask (Closed)
Patch Set: Fix test Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/core/prefetch/prefetch_dispatcher.h
diff --git a/components/offline_pages/core/prefetch/prefetch_dispatcher.h b/components/offline_pages/core/prefetch/prefetch_dispatcher.h
index b8d68de097aa38a2f1e8df3fc063ffd13478539f..37403f1ae6be88d0e772abf4ffac898ab2c13283 100644
--- a/components/offline_pages/core/prefetch/prefetch_dispatcher.h
+++ b/components/offline_pages/core/prefetch/prefetch_dispatcher.h
@@ -29,9 +29,9 @@ class PrefetchDispatcher {
ScopedBackgroundTask() = default;
virtual ~ScopedBackgroundTask() = default;
- // Used on destruction to inform the system about whether rescheduling is
- // required.
- virtual void SetNeedsReschedule(bool reschedule) = 0;
+ // Used on destruction to inform the system about whether rescheduling with
+ // or without backoff is required.
+ virtual void SetNeedsReschedule(bool reschedule, bool backoff) = 0;
};
virtual ~PrefetchDispatcher() = default;
@@ -65,7 +65,10 @@ class PrefetchDispatcher {
// Called when a task must stop immediately due to system constraints. After
// this call completes, the system will reschedule the task based on whether
// SetNeedsReschedule has been called.
- virtual void StopBackgroundTask(ScopedBackgroundTask* task) = 0;
+ virtual void StopBackgroundTask() = 0;
+
+ // Used by the test to signal the completion of the background task.
+ virtual void RequestFinishBackgroundTaskForTest() = 0;
};
} // namespace offline_pages

Powered by Google App Engine
This is Rietveld 408576698